@@ -31,6 +31,8 @@ class Borg:
     def __init__(self):
         self.__dict__ = self.__shared_state
 
+
+
     def is_first_time(self):
         "Has the child class been invoked before?"
         result_flag = False
@@ -52,23 +54,25 @@ class Assert(object):
            Assert.fail(message)
        """
 
-    @staticmethod
-    def assert_true(condition, message=None):
-        """Assert a condition is True
-        :param condition: condition to check
-        :param message: message to display in case of assertion failure
-        :return: None
-        """
-        assert_that(condition, equal_to(True), message)
+    # @staticmethod
+    # def assert_true(condition, message=None):
+    #     """Assert a condition is True
+    #     :param condition: condition to check
+    #     :param message: message to display in case of assertion failure
+    #     :return: None
+    #     """
+    #
+    #     assert_that(condition, equal_to(True), message)
 
-    @staticmethod
-    def assert_false(condition, message=None):
-        """Assert a condition is False
-        :param condition: condition to check
-        :param message: message to display in case of assertion failure
-        :return:
-        """
-        assert_that(condition, equal_to(False), message)
+    # @staticmethod
+    # def assert_false(condition, message=None):
+    #     """Assert a condition is False
+    #     :param condition: condition to check
+    #     :param message: message to display in case of assertion failure
+    #     :return:
+    #     """
+    #
+    #     assert_that(condition, equal_to(False), message)
 
     @staticmethod
     def assert_equals(actual, expected, message=None):
@@ -149,6 +153,7 @@ class Base_Page(Borg, unittest.TestCase):
             self.test_run_id = None
             self.start_time = None  # pytest have Unresolved attribute reference if not added
             self.test_env = ""  # pytest have Unresolved attribute reference if not added
+            self.non_breakable = ""
             self.reset()
         self.base_url = base_url
         self.driver_obj = DriverFactory()
@@ -295,6 +300,27 @@ class Base_Page(Borg, unittest.TestCase):
             self.write(str(e))
             self.exceptions.append("Error when setting up the screenshot directory")
 
+    @staticmethod
+    def assert_true(condition, message=None):
+        """Assert a condition is True
+        :param condition: condition to check
+        :param message: message to display in case of assertion failure
+        :return: None
+        """
+
+        assert_that(condition, equal_to(True), message)
+
+    @staticmethod
+    def assert_false(condition, message=None):
+        """Assert a condition is False
+        :param condition: condition to check
+        :param message: message to display in case of assertion failure
+        :return:
+        """
+
+        assert_that(condition, equal_to(False), message)
+
+
     def get_screenshot_dir(self, os_name, os_version, browser, browser_version, overwrite_flag=False):
         "Get the name of the test"
         if os_name == 'OS X':
